@@ -178,6 +178,10 @@ int pw_remote_connect(struct pw_remote *remote);
  * \return 0 on success, < 0 on error */
 int pw_remote_connect_fd(struct pw_remote *remote, int fd);
 
+/** Steal the fd of the remote connection or < 0 on error. The remote
+  * will be in the unconnected state after this call. */
+int pw_remote_steal_fd(struct pw_remote *remote);
+
 /** Get the core proxy, can only be called when connected */
 struct pw_core_proxy * pw_remote_get_core_proxy(struct pw_remote *remote);
 
@@ -188,10 +192,10 @@ const struct pw_core_info *pw_remote_get_core_info(struct pw_remote *remote);
 struct pw_proxy *pw_remote_find_proxy(struct pw_remote *remote, uint32_t id);
 
 /** Disconnect from the remote PipeWire. \memberof pw_remote */
-void pw_remote_disconnect(struct pw_remote *remote);
+int pw_remote_disconnect(struct pw_remote *remote);
 
 /** Update the state of the remote, mostly used by protocols */
-void pw_remote_update_state(struct pw_remote *remote, enum pw_remote_state state, const char *fmt, ...);
+int pw_remote_update_state(struct pw_remote *remote, enum pw_remote_state state, const char *fmt, ...);
 
 /** run a local node in a remote graph */
 struct pw_proxy *pw_remote_export(struct pw_remote *remote, struct pw_node *node);
